# Copyright 1999-2017. Plesk International GmbH. All rights reserved.
package ErrorReportSender;

use strict;
use warnings;

use AgentConfig;
use Logging;

sub new {
  my $self = {};
  bless($self, shift);
  return $self;
}

sub send {
  my ($self, $operation, $step, $message, $trace) = @_;

  Logging::debug("Sending feedback");

  eval {
    my $cmd = sprintf('%s pmm', AgentConfig::sendErrorReportBin());
    my $stdin = $self->_prepareContent($operation, $step, $message, $trace);
    $stdin =~ s/\n/\\n/g;
    Logging::debug("Execute: $cmd. Stdin: $stdin");
    $ENV{'FEEDBACK'} = $stdin;
    system(sprintf('/bin/echo -e $FEEDBACK | %s &', $cmd));
  };
  if ($@) {
    Logging::debug("Unable to send feedback: $@");
  }
}

sub _prepareContent {
    my ($self, $operation, $step, $message, $trace) = @_;

    my $report = XmlNode->new('error');
    $report->addChild(XmlNode->new('file', 'content' => "backup-agent, $operation, $step"));
    $report->addChild(XmlNode->new('line', 'content' => "0"));
    $report->addChild(XmlNode->new('message', 'content' => $message));
    $report->addChild(XmlNode->new('trace', 'content' => $trace));
    return $report->serialize();
}

1;