# Copyright 1999-2019. Plesk International GmbH. All rights reserved.
package RunMark;

use strict;
use warnings;

use AgentConfig;
use Fcntl;

sub new {
  my $self = {};
  bless($self, shift);
  $self->_init(@_);
  return $self;
}

sub DESTROY {
  my $self = shift;

  $self->clean();
}

sub _init {
  my ($self, $creationDate) = @_;

  $self->{markHandle} = undef;
  $self->{markPath} = sprintf("%s/%s", AgentConfig::runDir(), $creationDate);

  if ((not -d AgentConfig::runDir()) && !mkdir(AgentConfig::runDir())) {
    Logging::debug(sprintf("Failed to create the directory %s: %s", AgentConfig::runDir(), $!));
    return;
  }
  if (!sysopen($self->{markHandle}, $self->{markPath}, Fcntl::O_RDWR|Fcntl::O_CREAT)) {
    Logging::debug(sprintf("Failed to open the file %s: %s", $self->{markPath}, $!));
    return;
  }
  Logging::debug('Mark created');
  if (!flock($self->{markHandle}, Fcntl::LOCK_EX)) {
    Logging::debug(sprintf("Failed to lock the file %s: %s", $self->{markPath}, $!));
    return;
  }
}

sub clean {
  my $self = shift;

  if (defined($self->{markHandle})) {
    close($self->{markHandle});
    unlink($self->{markPath});
    $self->{markHandle} = undef;
  }
}

1;